==> lib-bb-portal-rest-nodejs-plugin-2.0.0.tgz: package/README.md <==
# lib-bb-portal-rest-nodejs-plugin
Adapter to configure lib-bb-portal-rest for nodejs

## INSTALL

- Install library

```bash
npm install --save @bb-cli/lib-bb-portal-rest-nodejs-plugin
```



## API
## Members

<dl>
<dt><a href="#default">default</a> ⇒</dt>
<dd></dd>
</dl>

## Typedefs

<dl>
<dt><a href="#requestCallback">requestCallback</a> ⇒ <code><a href="#Response">Response</a></code></dt>
<dd><p>Executes http request.</p>
</dd>
<dt><a href="#NodeJSAdapter">NodeJSAdapter</a> : <code>object</code></dt>
<dd></dd>
<dt><a href="#logCallback">logCallback</a> : <code>function</code></dt>
<dd><p>logs message with header</p>
</dd>
<dt><a href="#btoaCallback">btoaCallback</a> ⇒ <code>string</code></dt>
<dd><p>returns a base-64 encoded ASCII string from a String object</p>
</dd>
<dt><a href="#Response">Response</a> : <code>object</code></dt>
<dd></dd>
</dl>

<a name="default"></a>

## default ⇒
**Kind**: global variable  
**Returns**: NodeJSAdapter Adapter API  

| Param | Type | Description |
| --- | --- | --- |
| logFunction | <code>function</code> | function to use for logging |

<a name="requestCallback"></a>

## requestCallback ⇒ <code>[Response](#Response)</code>
Executes http request.

**Kind**: global typedef  
**Returns**: <code>[Response](#Response)</code> - response object  

| Param | Type | Description |
| --- | --- | --- |
| config | <code>object</code> | http request configuration |
| config.url | <code>string</code> | target url |
| config.method | <code>string</code> | http method |
| config.query | <code>object</code> | http param query hash |
| config.headers | <code>object</code> | headers hash |
| config.importFile | <code>string</code> | path of the file to upload |
| config.exportFile | <code>string</code> | path of the file to download to |
| config.formField | <code>string</code> | name of the form field for upload |
| payload | <code>string</code> | xml string or path of xml file to sent as request body |

<a name="NodeJSAdapter"></a>

## NodeJSAdapter : <code>object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| request | <code>[requestCallback](#requestCallback)</code> | http request method |
| log | <code>[logCallback](#logCallback)</code> | log method |
| btoa | <code>[btoaCallback](#btoaCallback)</code> | base64 string convert method |
| DOMParser | <code>DOMParser</code> | See [https://www.npmjs.com/package/xmldom](https://www.npmjs.com/package/xmldom) |

<a name="logCallback"></a>

## logCallback : <code>function</code>
logs message with header

**Kind**: global typedef  

| Param | Type | Description |
| --- | --- | --- |
| header | <code>string</code> | title of the message |
| message | <code>string</code> | message to log |

<a name="btoaCallback"></a>

## btoaCallback ⇒ <code>string</code>
returns a base-64 encoded ASCII string from a String object

**Kind**: global typedef  
**Returns**: <code>string</code> - encodedString  

| Param | Type | Description |
| --- | --- | --- |
| string | <code>string</code> | to encode |

<a name="Response"></a>

## Response : <code>object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| status | <code>number</code> | http status code |
| statusText | <code>string</code> | http status text |
| headers | <code>object</code> | http response headers |
| body | <code>string</code> | http response body |

==> lib-bb-portal-rest-nodejs-plugin-2.0.2.tgz: package/README.md <==
# lib-bb-portal-rest-nodejs-plugin
Adapter to configure lib-bb-portal-rest for nodejs

## INSTALL

- Install library

```bash
npm install --save @bb-cli/lib-bb-portal-rest-nodejs-plugin
```



## API
## Members

<dl>
<dt><a href="#default">default</a> ⇒</dt>
<dd></dd>
</dl>

## Typedefs

<dl>
<dt><a href="#requestCallback">requestCallback</a> ⇒ <code><a href="#Response">Response</a></code></dt>
<dd><p>Executes http request.</p>
</dd>
<dt><a href="#NodeJSAdapter">NodeJSAdapter</a> : <code>object</code></dt>
<dd></dd>
<dt><a href="#logCallback">logCallback</a> : <code>function</code></dt>
<dd><p>logs message with header</p>
</dd>
<dt><a href="#btoaCallback">btoaCallback</a> ⇒ <code>string</code></dt>
<dd><p>returns a base-64 encoded ASCII string from a String object</p>
</dd>
<dt><a href="#Response">Response</a> : <code>object</code></dt>
<dd></dd>
</dl>

<a name="default"></a>

## default ⇒
**Kind**: global variable  
**Returns**: NodeJSAdapter Adapter API  

| Param | Type | Description |
| --- | --- | --- |
| logFunction | <code>function</code> | function to use for logging |

<a name="requestCallback"></a>

## requestCallback ⇒ <code>[Response](#Response)</code>
Executes http request.

**Kind**: global typedef  
**Returns**: <code>[Response](#Response)</code> - response object  

| Param | Type | Description |
| --- | --- | --- |
| config | <code>object</code> | http request configuration |
| config.url | <code>string</code> | target url |
| config.method | <code>string</code> | http method |
| config.query | <code>object</code> | http param query hash |
| config.headers | <code>object</code> | headers hash |
| config.importFile | <code>string</code> | path of the file to upload |
| config.exportFile | <code>string</code> | path of the file to download to |
| config.formField | <code>string</code> | name of the form field for upload |
| payload | <code>string</code> | xml string or path of xml file to sent as request body |

<a name="NodeJSAdapter"></a>

## NodeJSAdapter : <code>object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| request | <code>[requestCallback](#requestCallback)</code> | http request method |
| log | <code>[logCallback](#logCallback)</code> | log method |
| btoa | <code>[btoaCallback](#btoaCallback)</code> | base64 string convert method |
| DOMParser | <code>DOMParser</code> | DOMParser API |

<a name="logCallback"></a>

## logCallback : <code>function</code>
logs message with header

**Kind**: global typedef  

| Param | Type | Description |
| --- | --- | --- |
| header | <code>string</code> | title of the message |
| message | <code>string</code> | message to log |

<a name="btoaCallback"></a>

## btoaCallback ⇒ <code>string</code>
returns a base-64 encoded ASCII string from a String object

**Kind**: global typedef  
**Returns**: <code>string</code> - encodedString  

| Param | Type | Description |
| --- | --- | --- |
| string | <code>string</code> | to encode |

<a name="Response"></a>

## Response : <code>object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| status | <code>number</code> | http status code |
| statusText | <code>string</code> | http status text |
| headers | <code>object</code> | http response headers |
| body | <code>string</code> | http response body |
